@@ -1,8 +1,13 @@
+"""
+Sparse solvers wrapper.
+"""
+
+import logging
+
 from scipy.sparse import csc_matrix
 from scipy.sparse.linalg import spsolve
 from andes.shared import np, matrix, umfpack, klu, cupy
 
-import logging
 logger = logging.getLogger(__name__)
 
 
@@ -37,9 +42,9 @@ class Solver:
 
         Parameters
         ----------
-        A : cvxopt.spmatrix
+        A : kvxopt.spmatrix
             Sparse N-by-N matrix
-        b : cvxopt.matrix or numpy.ndarray
+        b : kvxopt.matrix or numpy.ndarray
             Dense N-by-1 matrix
 
         Returns
@@ -55,9 +60,9 @@ class Solver:
 
         Parameters
         ----------
-        A : cvxopt.spmatrix
+        A : kvxopt.spmatrix
             Sparse N-by-N matrix
-        b : cvxopt.matrix or numpy.ndarray
+        b : kvxopt.matrix or numpy.ndarray
             Dense N-by-1 matrix
 
         Returns
@@ -113,7 +118,7 @@ class SuiteSparseSolver:
         -------
         A C-object of the symbolic factorization.
         """
-        pass
+        return None
 
     def _numeric(self, A, F):
         """
@@ -130,7 +135,7 @@ class SuiteSparseSolver:
         -------
         The numeric factorization of ``A``.
         """
-        pass
+        return None
 
     def _solve(self, A, F, N, b):
         """
@@ -149,9 +154,9 @@ class SuiteSparseSolver:
 
         Returns
         -------
-        The solution as a ``cvxopt.matrix``.
+        The solution as a ``kvxopt.matrix``.
         """
-        pass
+        return None
 
     def solve(self, A, b):
         """
@@ -192,8 +197,7 @@ class SuiteSparseSolver:
         except ValueError:
             logger.debug('Unexpected symbolic factorization.')
             self.F = self._symbolic(self.A)
-            self.N = self._numeric(self.A, self.F)
-            self._solve(self.A, self.F, self.N, self.b)
+            self.solve(self.A, self.b)
 
             return np.ravel(self.b)
         except ArithmeticError:
@@ -231,7 +235,7 @@ class UMFPACKSolver(SuiteSparseSolver):
     """
     UMFPACK solver.
 
-    Utilizes ``cvxopt.umfpack`` for factorization.
+    Utilizes ``kvxopt.umfpack`` for factorization.
     """
     def __init__(self):
         super().__init__()
@@ -257,7 +261,7 @@ class KLUSolver(SuiteSparseSolver):
     """
     KLU solver.
 
-    Requires package ``cvxoptklu``.
+    Requires package ``kvxoptklu``.
     """
     def __init__(self):
         super().__init__()
@@ -292,7 +296,7 @@ class SciPySolver:
 
         Parameters
         ----------
-        A : cvxopt.spmatrix
+        A : kvxopt.spmatrix
             Sparse N-by-N matrix
 
         Returns
