@@ -1,4 +1,4 @@
-#  [ANDES] (C)2015-2020 Hantao Cui
+#  [ANDES] (C)2015-2021 Hantao Cui
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ from andes.core.common import DummyValue
 from andes.core.discrete import Discrete
 from andes.core.service import BaseService
 from andes.models.group import GroupBase
-from andes.shared import np, ndarray
+from andes.shared import np
 
 
 class BaseVar:
@@ -87,12 +87,13 @@ class BaseVar:
 
         # attributes assigned by `set_address`
         self.n = 0
-        self.a: ndarray = np.array([], dtype=int)       # address array
-        self.v: ndarray = np.array([], dtype=np.float)  # variable value array
-        self.e: ndarray = np.array([], dtype=np.float)  # equation value array
+        self.a: np.ndarray = np.array([], dtype=int)       # address array
+        self.r: np.ndarray = np.array([], dtype=int)       # equation RHS value array for external equations
+        self.v: np.ndarray = np.array([], dtype=float)     # variable value array
+        self.e: np.ndarray = np.array([], dtype=float)     # equation value array
 
-        self.av: ndarray = np.array([], dtype=int)      # FIXME: future var. address array
-        self.ae: ndarray = np.array([], dtype=int)      # FIXME: future equation address array
+        self.av: np.ndarray = np.array([], dtype=int)      # FIXME: future var. address array
+        self.ae: np.ndarray = np.array([], dtype=int)      # FIXME: future equation address array
 
         # internal flags
         # NOTE:
@@ -136,13 +137,13 @@ class BaseVar:
 
         return f'{self.__class__.__name__}: {self.owner.__class__.__name__}.{self.name}, {span}'
 
-    def set_address(self, addr: ndarray, contiguous=False):
+    def set_address(self, addr: np.ndarray, contiguous=False):
         """
         Set the address of internal variables.
 
         Parameters
         ----------
-        addr : ndarray
+        addr : np.ndarray
             The assigned address for this variable
         contiguous : bool, optional
             If the addresses are contiguous
@@ -164,26 +165,45 @@ class BaseVar:
             if self.v_setter is False:
                 self.v_inplace = True
 
-    def set_arrays(self, dae):
+    def set_arrays(self, dae, inplace=True, alloc=True):
         """
         Set the equation and values arrays.
 
-        It slicing into DAE (when contiguous) or allocating new memory (when not contiguous).
 
         Parameters
         ----------
         dae : DAE
             Reference to System.dae
         """
+        if inplace is True:
+            self._set_arrays_inplace(dae)
+        if alloc is True:
+            self._set_arrays_alloc()
+
+    def _set_arrays_inplace(self, dae):
+        """
+        Set arrays that share memory with the dae arrays.
+
+        It slicing into DAE due to the contiguous indices.
+        """
+
         slice_idx = slice(self.a[0], self.a[-1] + 1)
         if self.v_inplace:
             self.v = dae.__dict__[self.v_code][slice_idx]
-        else:
-            self.v = np.zeros(self.n)
 
         if self.e_inplace:
             self.e = dae.__dict__[self.e_code][slice_idx]
-        else:
+
+    def _set_arrays_alloc(self):
+        """
+        Allocate for internal v and e arrays that cannot
+        share memory with dae arrays.
+        """
+
+        if not self.v_inplace:
+            self.v = np.zeros(self.n)
+
+        if not self.e_inplace:
             self.e = np.zeros(self.n)
 
     def get_names(self):
@@ -219,6 +239,10 @@ class State(BaseVar):
         Left-hand time constant for the differential equation.
         Time constants will not be evaluated as part of the differential equation.
         They will be collected to array `dae.Tf` to multiply to the right-hand side `dae.f`.
+    check_init : bool
+        True to check if the equation right-hand-side is zero
+        initially. Disabling the checking can be used for integrators
+        when the initial input may not be zero.
 
     Attributes
     ----------
@@ -240,6 +264,7 @@ class State(BaseVar):
                  e_str: Optional[str] = None,
                  discrete: Optional[Discrete] = None,
                  t_const: Optional[Union[BaseParam, DummyValue, BaseService]] = None,
+                 check_init: Optional[bool] = True,
                  v_setter: Optional[bool] = False,
                  e_setter: Optional[bool] = False,
                  addressable: Optional[bool] = True,
@@ -261,6 +286,7 @@ class State(BaseVar):
                          diag_eps=diag_eps,
                          )
         self.t_const = t_const
+        self.check_init = check_init
 
 
 class ExtVar(BaseVar):
@@ -299,7 +325,7 @@ class ExtVar(BaseVar):
     def __init__(self,
                  model: str,
                  src: str,
-                 indexer: Optional[Union[List, ndarray, BaseParam, BaseService]] = None,
+                 indexer: Optional[Union[List, np.ndarray, BaseParam, BaseService]] = None,
                  allow_none: Optional[bool] = False,
                  name: Optional[str] = None,
                  tex_name: Optional[str] = None,
@@ -356,13 +382,22 @@ class ExtVar(BaseVar):
 
     def set_address(self, addr, contiguous=False):
         """
-        Empty function.
+        Assigns address for equation RHS.
         """
-        pass
+        self.r = addr
 
-    def set_arrays(self, dae):
-        """Empty function."""
-        pass
+    def set_arrays(self, dae, inplace=True, alloc=True):
+        """
+        Stride of ``dae.i`` for the RHS of external variables.
+        """
+
+        slice_idx = slice(self.r[0], self.r[-1] + 1)
+        if isinstance(self, ExtState):
+            self.e = dae.h[slice_idx]
+        elif isinstance(self, ExtAlgeb):
+            self.e = dae.i[slice_idx]
+        else:
+            raise NotImplementedError
 
     def link_external(self, ext_model):
         """
@@ -414,6 +449,10 @@ class ExtVar(BaseVar):
 
             if self.allow_none:
                 raise NotImplementedError(f"{self.name}: allow_none not implemented for Model")
+            if original_var.v_code != self.v_code:
+                raise TypeError("Linking %s of %s to %s of %s is not allowed" %
+                                (self.name, self.class_name,
+                                 original_var.name, original_var.class_name))
 
             if self.indexer is not None:
                 uid = ext_model.idx2uid(self.indexer.v)
@@ -430,7 +469,7 @@ class ExtVar(BaseVar):
             self.n = len(self.a)
 
         self.v = np.zeros(self.n)
-        self.e = np.zeros(self.n)
+        # `self.e` is assigned in `set_arrays()`
 
 
 class ExtState(ExtVar):
