@@ -8,17 +8,24 @@ import logging
 import re
 import os
 
+import andes.io
+
 from andes.shared import deg2rad, pd, yaml
 from andes.utils.misc import to_number
 from collections import defaultdict
 logger = logging.getLogger(__name__)
 
 
-def testlines(fid):
+def testlines(infile):
     """
-    Check the raw file for frequency base
+    Check the raw file for frequency base.
     """
-    first = fid.readline()
+    lines_list = andes.io.read_file_like(infile)
+
+    if len(lines_list) == 0:
+        return False
+
+    first = lines_list[0]
     first = first.strip().split('/')
     first = first[0].split(',')
 
@@ -38,8 +45,9 @@ def testlines(fid):
 
 def get_block_lines(b, mdata):
     """
-    Return the number of lines based on data
+    Return the number of lines based on the block index in the RAW file.
     """
+
     line_counts = [1, 1, 1, 1, 1, 4, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 0]
 
     if b == 5:  # for transformer
@@ -52,7 +60,9 @@ def get_block_lines(b, mdata):
 
 
 def read(system, file):
-    """read PSS/E RAW file v32 format"""
+    """
+    Read PSS/E RAW file v32/v33 formats.
+    """
 
     blocks = [
         'bus', 'load', 'fshunt', 'gen', 'branch', 'transf', 'area',
@@ -74,8 +84,7 @@ def read(system, file):
     dev_line = 0  # line counter for multi-line models
 
     # read file into `line_list`
-    with open(file, 'r') as f:
-        line_list = [line.rstrip('\n') for line in f]
+    line_list = andes.io.read_file_like(file)
 
     # parse file into `raw` with to_number conversions
     for num, line in enumerate(line_list):
@@ -147,8 +156,7 @@ def _read_dyr_dict(file):
     """
     Parse dyr file into a dict where keys are model names and values are dataframes.
     """
-    with open(file, 'r') as f:
-        input_list = [line.strip() for line in f]
+    input_list = andes.io.read_file_like(file)
 
     # concatenate multi-line device data
     input_concat_dict = defaultdict(list)
@@ -288,7 +296,13 @@ def read_add(system, file):
                     args, func = expr.split(';')
                     func = eval(func)
                     args = args.split(',')
-                    argv = [pairs.split('.') for pairs in args]
+                    # support local and external model parameters
+                    argv = list()
+                    for param in args:
+                        if '.' in param:
+                            argv.append(param.split('.'))
+                        else:
+                            argv.append((psse_model, param))
                     argv = [dyr_dict[model][param] for model, param in argv]
                     out_dict[output_keys[idx]] = func(*argv)
                 else:
@@ -465,11 +479,9 @@ def _parse_transf_v33(raw, system, max_bus):
             phi = data[2][2] * deg2rad  # `ANG1` is entered in degree; convert to rad
 
             # CW - Winding I/O code, 1-turn ratio on pu bus base kV, 2: winding V, 3: turn ratio pu on norn wind V
-            if data[0][4] == 1:
-                tap = tap
-            elif data[0][4] == 2:
+            if data[0][4] == 2:
                 tap = (data[2][0] / bus_Vn1) / (data[3][0] / bus_Vn2)
-            else:
+            elif data[0][4] == 3:
                 tap = tap * (Vn1 / bus_Vn1) / (Vn2 / bus_Vn2)
 
             # CZ - Z code, 1-system base, 2-winding base, 3-load loss and |z|
