@@ -11,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 class GroupBase:
     """
-    Base class for groups
+    Base class for groups.
     """
 
     def __init__(self):
@@ -122,7 +122,7 @@ class GroupBase:
                 else:
                     ret.append(self._idx2model[i])
             except KeyError:
-                raise KeyError(f'Group <{self.class_name}> does not contain idx <{i}>')
+                raise KeyError(f'Group <{self.class_name}> does not contain device with idx={i}')
 
         if single:
             ret = ret[0]
@@ -455,6 +455,13 @@ class ACLine(GroupBase):
         self.common_vars.extend(('v1', 'v2', 'a1', 'a2'))
 
 
+class ACShort(GroupBase):
+    def __init__(self):
+        super(ACShort, self).__init__()
+        self.common_params.extend(('bus1', 'bus2'))
+        self.common_vars.extend(('v1', 'v2', 'a1', 'a2'))
+
+
 class StaticLoad(GroupBase):
     """
     Static load group.
@@ -469,6 +476,13 @@ class StaticShunt(GroupBase):
     pass
 
 
+class DynLoad(GroupBase):
+    """
+    Dynamic load group.
+    """
+    pass
+
+
 class SynGen(GroupBase):
     """
     Synchronous generator group.
@@ -491,7 +505,7 @@ class RenGen(GroupBase):
 
     def __init__(self):
         super().__init__()
-        self.common_params.extend(('bus', 'gen'))
+        self.common_params.extend(('bus', 'gen', 'Sn'))
         self.common_vars.extend(('Ipcmd', 'Iqcmd', 'Pe', 'Qe'))
 
 
@@ -499,6 +513,7 @@ class RenExciter(GroupBase):
     """
     Renewable electrical control (exciter) group.
     """
+
     def __init__(self):
         super().__init__()
         self.common_params.extend(('reg',))
@@ -509,6 +524,7 @@ class RenPlant(GroupBase):
     """
     Renewable plant control group.
     """
+
     def __init__(self):
         super().__init__()
 
@@ -517,6 +533,7 @@ class RenGovernor(GroupBase):
     """
     Renewable turbine governor group.
     """
+
     def __init__(self):
         super().__init__()
         self.common_params.extend(('ree', 'w0', 'Sn', 'Pe0'))
@@ -527,6 +544,7 @@ class RenAerodynamics(GroupBase):
     """
     Renewable aerodynamics group.
     """
+
     def __init__(self):
         super().__init__()
         self.common_params.extend(('rego',))
@@ -537,6 +555,7 @@ class RenPitch(GroupBase):
     """
     Renewable generator pitch controller group.
     """
+
     def __init__(self):
         super().__init__()
         self.common_params.extend(('rea',))
@@ -546,6 +565,7 @@ class RenTorque(GroupBase):
     """
     Renewable torque (Pref) controller.
     """
+
     def __init__(self):
         super().__init__()
 
@@ -554,6 +574,7 @@ class DG(GroupBase):
     """
     Distributed generation (small-scale).
     """
+
     def __init__(self):
         super().__init__()
 
@@ -628,5 +649,16 @@ class PhasorMeasurement(GroupBase):
 class Motor(GroupBase):
     """Induction Motor group
     """
+
     def __init__(self):
         super().__init__()
+
+
+class Information(GroupBase):
+    """
+    Group for information container models.
+    """
+
+    def __init__(self):
+        GroupBase.__init__(self)
+        self.common_params = []
