@@ -2,14 +2,15 @@
 Synchronous generator classes
 """
 import logging
+
 from andes.core.model import Model, ModelData
-from andes.models.exciter import ExcQuadSat
 from andes.core.param import IdxParam, NumParam, ExtParam
 from andes.core.var import Algeb, State, ExtAlgeb
 from andes.core.discrete import LessThan
-from andes.core.service import ConstService, VarService, ExtService  # NOQA
+from andes.core.service import ConstService, ExtService
 from andes.core.service import InitChecker, FlagValue
-import numpy as np
+
+from andes.models.exciter import ExcQuadSat
 
 logger = logging.getLogger(__name__)
 
@@ -66,11 +67,11 @@ class GENBaseData(ModelData):
                             info='d-axis transient reactance',
                             tex_name=r"x'_d", z=True)
 
-        self.kp = NumParam(default=0,
+        self.kp = NumParam(default=0.0,
                            info="active power feedback gain",
                            tex_name='k_p'
                            )
-        self.kw = NumParam(default=0,
+        self.kw = NumParam(default=0.0,
                            info="speed feedback gain",
                            tex_name='k_w'
                            )
@@ -82,9 +83,23 @@ class GENBaseData(ModelData):
                             info="second saturation factor",
                             tex_name='S_{1.2}',
                             )
+        self.gammap = NumParam(default=1.0,
+                               info="P ratio of linked static gen",
+                               tex_name=r'\gamma_P'
+                               )
+        self.gammaq = NumParam(default=1.0,
+                               info="Q ratio of linked static gen",
+                               tex_name=r'\gamma_Q'
+                               )
 
 
 class GENBase(Model):
+    """
+    Base class for synchronous generators.
+
+    Defines shared network and dq-component variables.
+    """
+
     def __init__(self, system, config):
         super().__init__(system, config)
         self.group = 'SynGen'
@@ -159,7 +174,7 @@ class GENBase(Model):
                         )
         self.te = Algeb(info='electric torque',
                         tex_name=r'\tau_e',
-                        v_str='u * p0',
+                        v_str='u * tm0',
                         e_str='u * (psid * Iq - psiq * Id) - te',
                         )
         self.vf = Algeb(info='excitation voltage',
@@ -200,16 +215,26 @@ class GENBase(Model):
                                 )
 
         # ----------service consts for initialization----------
-        self.p0 = ExtService(model='StaticGen',
-                             src='p',
-                             indexer=self.gen,
-                             tex_name='P_0',
-                             )
-        self.q0 = ExtService(model='StaticGen',
-                             src='q',
-                             indexer=self.gen,
-                             tex_name='Q_0',
-                             )
+        self.p0s = ExtService(model='StaticGen',
+                              src='p',
+                              indexer=self.gen,
+                              tex_name='P_{0s}',
+                              info='initial P of the static gen',
+                              )
+        self.q0s = ExtService(model='StaticGen',
+                              src='q',
+                              indexer=self.gen,
+                              tex_name='Q_{0s}',
+                              info='initial Q of the static gen',
+                              )
+        self.p0 = ConstService(v_str='p0s * gammap',
+                               tex_name='P_0',
+                               info='initial P of this gen',
+                               )
+        self.q0 = ConstService(v_str='q0s * gammaq',
+                               tex_name='Q_0',
+                               info='initial Q of this gen',
+                               )
 
     def v_numeric(self, **kwargs):
         # disable corresponding `StaticGen`
@@ -286,24 +311,24 @@ class GENCLSModel:
                              )
         self._V = ConstService(v_str='v * exp(1j * a)',
                                tex_name='V_c',
-                               vtype=np.complex,
+                               vtype=complex,
                                )
         self._S = ConstService(v_str='p0 - 1j * q0',
                                tex_name='S',
-                               vtype=np.complex,
+                               vtype=complex,
                                )
         self._I = ConstService(v_str='_S / conj(_V)',
                                tex_name='I_c',
-                               vtype=np.complex,
+                               vtype=complex,
                                )
-        self._E = ConstService(tex_name='E', vtype=np.complex)
-        self._deltac = ConstService(tex_name=r'\delta_c', vtype=np.complex)
+        self._E = ConstService(tex_name='E', vtype=complex)
+        self._deltac = ConstService(tex_name=r'\delta_c', vtype=complex)
         self.delta0 = ConstService(tex_name=r'\delta_0')
 
         self.vdq = ConstService(v_str='u * (_V * exp(1j * 0.5 * pi - _deltac))',
-                                tex_name='V_{dq}', vtype=np.complex)
+                                tex_name='V_{dq}', vtype=complex)
         self.Idq = ConstService(v_str='u * (_I * exp(1j * 0.5 * pi - _deltac))',
-                                tex_name='I_{dq}', vtype=np.complex)
+                                tex_name='I_{dq}', vtype=complex)
 
         self.Id0 = ConstService(v_str='re(Idq)',
                                 tex_name=r'I_{d0}')
@@ -333,6 +358,10 @@ class GENCLSModel:
 
 
 class GENCLS(GENBaseData, GENBase, GENCLSModel, Flux0):
+    """
+    Classical generator model.
+    """
+
     def __init__(self, system, config):
         GENBaseData.__init__(self)
         GENBase.__init__(self, system, config)
@@ -403,19 +432,19 @@ class GENROUModel:
 
         # internal voltage and rotor angle calculation
         self._V = ConstService(v_str='v * exp(1j * a)', tex_name='V_c', info='complex bus voltage',
-                               vtype=np.complex)
+                               vtype=complex)
         self._S = ConstService(v_str='p0 - 1j * q0', tex_name='S', info='complex terminal power',
-                               vtype=np.complex)
+                               vtype=complex)
         self._Zs = ConstService(v_str='ra + 1j * xd2', tex_name='Z_s', info='equivalent impedance',
-                                vtype=np.complex)
+                                vtype=complex)
         self._It = ConstService(v_str='_S / conj(_V)', tex_name='I_t', info='complex terminal current',
-                                vtype=np.complex)
+                                vtype=complex)
         self._Is = ConstService(tex_name='I_s', v_str='_It + _V / _Zs', info='equivalent current source',
-                                vtype=np.complex)
+                                vtype=complex)
 
         self.psi20 = ConstService(tex_name=r"\psi''_0", v_str='_Is * _Zs',
                                   info='sub-transient flux linkage in stator reference',
-                                  vtype=np.complex)
+                                  vtype=complex)
         self.psi20_arg = ConstService(tex_name=r"\theta_{\psi''0}", v_str='arg(psi20)')
         self.psi20_abs = ConstService(tex_name=r"|\psi''_0|", v_str='abs(psi20)')
         self._It_arg = ConstService(tex_name=r"\theta_{It0}", v_str='arg(_It)')
@@ -423,7 +452,7 @@ class GENROUModel:
                                           v_str='psi20_arg - _It_arg')
 
         self.Se0 = ConstService(tex_name=r"S_{e0}",
-                                v_str='(psi20_abs>=SAT_A) * (psi20_abs - SAT_A) ** 2 * SAT_B / psi20_abs')
+                                v_str='Indicator(psi20_abs>=SAT_A) * (psi20_abs - SAT_A) ** 2 * SAT_B / psi20_abs')
 
         self._a = ConstService(tex_name=r"a'", v_str='psi20_abs * (1 + Se0*gqd)')
         self._b = ConstService(tex_name=r"b'", v_str='abs(_It) * (xq2 - xq)')  # xd2 == xq2
@@ -433,13 +462,13 @@ class GENROUModel:
                                          'psi20_arg')
         self._Tdq = ConstService(tex_name=r"T_{dq}",
                                  v_str='cos(delta0) - 1j * sin(delta0)',
-                                 vtype=np.complex)
+                                 vtype=complex)
         self.psi20_dq = ConstService(tex_name=r"\psi''_{0,dq}",
                                      v_str='psi20 * _Tdq',
-                                     vtype=np.complex)
+                                     vtype=complex)
         self.It_dq = ConstService(tex_name=r"I_{t,dq}",
                                   v_str='conj(_It * _Tdq)',
-                                  vtype=np.complex)
+                                  vtype=complex)
 
         self.psi2d0 = ConstService(tex_name=r"\psi_{ad0}",
                                    v_str='re(psi20_dq)')
@@ -546,7 +575,7 @@ class GENROUModel:
 
 class GENROU(GENROUData, GENBase, GENROUModel, Flux0):
     """
-    Round rotor generator with quadratic saturation
+    Round rotor generator with quadratic saturation.
     """
     def __init__(self, system, config):
         GENROUData.__init__(self)
