@@ -2,14 +2,16 @@
 The Andes plotting tool.
 """
 
-import logging
 import os
 import re
-from distutils.spawn import find_executable
+import logging
 
-from andes.core.var import BaseVar, Algeb, ExtAlgeb, AliasAlgeb
-from andes.utils.paths import get_dot_andes_path
-from andes.shared import np, mpl, plt
+import numpy as np
+
+from andes.shared import mpl, plt
+from andes.shared import set_latex
+
+from andes.core.var import BaseVar
 
 logger = logging.getLogger(__name__)
 
@@ -53,7 +55,14 @@ class TDSData:
         self._process_names()
 
     def _process_names(self):
-        self.file_name, self.file_ext = os.path.splitext(self.full_name)
+        if self.full_name is None:
+            logger.info("Input file name not detected. Using `Untitled`.")
+            self.full_name = 'Untitled'
+            self.file_name = 'Untitled'
+            self.file_ext = ''
+        else:
+            self.file_name, self.file_ext = os.path.splitext(self.full_name)
+
         self._npy_file = os.path.join(self._path, self.file_name + '.npy')
 
         npz_path = os.path.join(self._path, self.file_name + '.npz')
@@ -261,6 +270,7 @@ class TDSData:
              title=None, linestyles=None, use_bqplot=False,
              hline1=None, hline2=None, vline1=None, vline2=None,
              fig=None, ax=None, backend=None,
+             set_xlim=True, set_ylim=True, autoscale=False, legend_bbox=None, legend_loc=None,
              **kwargs):
         """
         Entry function for plotting.
@@ -353,7 +363,7 @@ class TDSData:
                     logger.error(f"Variable <{yidx.name}> contains no values.")
                     return
                 offs = 1
-                if isinstance(yidx, (Algeb, ExtAlgeb, AliasAlgeb)):
+                if yidx.v_code == 'y':
                     offs += self.dae.n
 
                 yidx = yidx.a + offs
@@ -391,6 +401,8 @@ class TDSData:
                          savefig=savefig, save_format=save_format, show=show, title=title,
                          hline1=hline1, hline2=hline2, vline1=vline1, vline2=vline2,
                          fig=fig, ax=ax, linestyles=linestyles,
+                         set_xlim=set_xlim, set_ylim=set_ylim, autoscale=autoscale,
+                         legend_bbox=legend_bbox, legend_loc=legend_loc,
                          **kwargs)
 
     def get_call(self, backend=None):
@@ -424,7 +436,7 @@ class TDSData:
 
         from bqplot import pyplot as plt
         if not isinstance(ydata, np.ndarray):
-            TypeError("ydata must be numpy array. Retrieve with get_values().")
+            raise TypeError("ydata must be numpy array. Retrieve with `get_values()`.")
 
         if ydata.ndim == 1:
             ydata = ydata.reshape((-1, 1))
@@ -448,7 +460,9 @@ class TDSData:
                   left=None, right=None, ymin=None, ymax=None, legend=None, grid=False, fig=None, ax=None,
                   latex=True, dpi=150, line_width=1.0, font_size=12, greyscale=False, savefig=None,
                   save_format=None, show=True, title=None, hline1=None, hline2=None, vline1=None,
-                  vline2=None, **kwargs):
+                  vline2=None, set_xlim=True, set_ylim=True, autoscale=False,
+                  legend_bbox=None, legend_loc=None,
+                  **kwargs):
         """
         Plot lines for the supplied data and options.
 
@@ -469,18 +483,33 @@ class TDSData:
         -------
         (fig, ax)
             The figure and axis handles
+
+        Examples
+        --------
+        To plot the results of arithmetic calculation of variables, retrieve the values,
+        do the calculation, and plot with `plot_data`.
+
+        >>> v = ss.dae.ts.y[:, ss.PVD1.v.a]
+        >>> Ipcmd = ss.dae.ts.y[:, ss.PVD1.Ipcmd_y.a]
+        >>> t = ss.dae.ts.t
+
+        >>> ss.TDS.plt.plot_data(t, v * Ipcmd,
+        >>>                      xlabel='Time [s]',
+        >>>                      ylabel='Ipcmd [pu]')
+
         """
-        mpl.rc('font', family='Arial', size=font_size)
+        mpl.rc('font', family='serif', size=font_size)
 
         if not isinstance(ydata, np.ndarray):
-            TypeError("ydata must be a numpy array. Retrieve with get_values().")
+            raise TypeError("ydata must be a numpy array. Retrieve with get_values().")
 
         if ydata.ndim == 1:
             ydata = ydata.reshape((-1, 1))
 
         n_lines = ydata.shape[1]
 
-        set_latex(latex)
+        if latex:
+            set_latex()
 
         # set default x min based on simulation time
         if not left:
@@ -493,11 +522,9 @@ class TDSData:
 
         linestyles = linestyles * int(n_lines / len(linestyles) + 1)
 
-        hold = True
-        if not (fig and ax):
+        if fig is None or ax is None:
             fig = plt.figure(dpi=dpi)
             ax = plt.gca()
-            hold = False
 
         if greyscale:
             plt.gray()
@@ -513,7 +540,7 @@ class TDSData:
 
         if xlabel is not None:
             ax.set_xlabel(xlabel)
-        else:
+        elif xheader is not None and len(xheader) > 0:
             ax.set_xlabel(xheader[0])
 
         if ylabel:
@@ -521,10 +548,11 @@ class TDSData:
 
         ax.ticklabel_format(useOffset=False)
 
-        if not hold:
+        if set_xlim is True:
             ax.set_xlim(left=left, right=right)
+        if set_ylim is True:
             ax.set_ylim(bottom=ymin, top=ymax)
-        else:
+        if autoscale is True:
             ax.autoscale(axis='y')
 
         if grid:
@@ -537,7 +565,7 @@ class TDSData:
                 legend = True
 
         if legend:
-            ax.legend()
+            ax.legend(bbox_to_anchor=legend_bbox, loc=legend_loc)
 
         if title:
             ax.set_title(title)
@@ -570,13 +598,85 @@ class TDSData:
                 count += 1
 
             fig.savefig(outfile, dpi=dpi)
-            logger.info(f'Figure saved to "{outfile}".')
+            logger.info('Figure saved to "%s".', outfile)
 
         if show:
             plt.show()
 
         return fig, ax
 
+    def plotn(self, nrows: int, ncols: int, yidxes, xidxes=None, *, dpi=150, titles=None,
+              a=None, figsize=None, xlabel=None, ylabel=None, sharex=None, sharey=None, show=True,
+              xlabel_offs=(0.5, 0.01), ylabel_offs=(0.05, 0.5), hspace=0.2, wspace=0.2,
+              **kwargs):
+        """
+        Plot multiple subfigures in one figure.
+
+        Parameters ``xidxes``, ``a``, ``xlabels`` and ``ylabels``, if provided,
+        must have the same length as ``yidxes``.
+
+        Parameters
+        ----------
+        nrows : int
+            number of rows
+        ncols : int
+            number of cols
+        yidx
+            A list of `BaseVar` or index lists.
+        """
+
+        nyidxes = len(yidxes)
+        if nyidxes > nrows * ncols:
+            raise ValueError("yidxes with length %d does not fit nrows=%d and ncols=%d",
+                             nyidxes, nrows, ncols)
+
+        fig = plt.figure(figsize=figsize, dpi=dpi)
+
+        xidx = (0,)
+        aidx = None
+        title = ''
+
+        # assume the first xlabel
+        xlabel = self.get_header(xidx)[0] if xlabel is None else xlabel
+
+        sharex = True if (sharex is None and ncols == 1) else False
+        sharey = True if (sharey is None and nrows == 1) else False
+
+        axes = fig.subplots(nrows, ncols, sharex=sharex, sharey=sharey, squeeze=False)
+
+        ii = 0
+        for jj in range(nrows):
+            for kk in range(ncols):
+                if ii >= nyidxes:
+                    break
+
+                yidx = yidxes[ii]
+                ax = axes[jj, kk]
+                if xidxes is not None:
+                    xidx = xidxes[ii]
+
+                if a is not None:
+                    aidx = a[ii]
+
+                if titles is not None:
+                    title = titles[ii]
+
+                fig, ax = self.plot(yidx, xidx, a=aidx, fig=fig, ax=ax,
+                                    xlabel='', ylabel='', title=title,
+                                    show=False, **kwargs)
+                ii += 1
+        if xlabel:
+            fig.text(*xlabel_offs, xlabel, ha='center', va='center')
+        if ylabel:
+            fig.text(*ylabel_offs, ylabel, ha='center', va='center', rotation='vertical')
+
+        fig.subplots_adjust(hspace=hspace, wspace=wspace,)
+
+        if show:
+            plt.show()
+
+        return fig, axes
+
 
 def parse_y(y, upper, lower=0):
     """
@@ -654,22 +754,6 @@ def parse_y(y, upper, lower=0):
         return list(y_in_range)
 
 
-def add_plot(x, y, xl, yl, fig, ax, LATEX=False, linestyle=None, **kwargs):
-    """Add plots to an existing plot"""
-    if LATEX:
-        # xl_data = xl[1]  # NOQA
-        yl_data = yl[1]
-    else:
-        # xl_data = xl[0]  # NOQA
-        yl_data = yl[0]
-
-    for idx, y_val in enumerate(y):
-        ax.plot(x, y_val, label=yl_data[idx], linestyle=linestyle)
-
-    ax.legend(loc='upper right')
-    ax.set_ylim(auto=True)
-
-
 def eig_plot(name, args):
     fullpath = os.path.join(name, '.txt')
     raw_data = []
@@ -816,43 +900,3 @@ def label_latexify(label):
         A string with $ surrounding
     """
     return '$' + label.replace(' ', r'\ ') + '$'
-
-
-def set_latex(enable=True):
-    """
-    Enables LaTeX for matplotlib based on the `with_latex` option and `dvipng` availability.
-
-    Parameters
-    ----------
-    enable : bool, optional
-        True for latex on and False for off
-
-    Returns
-    -------
-    bool
-        True for LaTeX on, False for off
-    """
-
-    has_dvipng = find_executable('dvipng')
-
-    if has_dvipng and enable:
-        mpl.rc('text', usetex=True)
-
-        no_warn_file = os.path.join(get_dot_andes_path(), '.no_warn_latex')
-        if not os.path.isfile(no_warn_file):
-            logger.info('Info:')
-            logger.info('Using LaTeX for rendering. If an error occurs:')
-            logger.info('a) If you are using `andes plot`, disable with option "-d",')
-            logger.info('b) If you are using `plot()`, set "latex=False".')
-
-            try:
-                with open(os.path.join(get_dot_andes_path(), '.no_warn_latex'), 'w'):
-                    pass
-            except OSError:
-                pass
-
-        return True
-
-    else:
-        mpl.rc('text', usetex=False)
-        return False
