@@ -22,6 +22,7 @@ class TDS(BaseRoutine):
     """
     Time-domain simulation routine.
     """
+
     def __init__(self, system=None, config=None):
         super().__init__(system, config)
         self.config.add(OrderedDict((('tol', 1e-6),
@@ -33,9 +34,13 @@ class TDS(BaseRoutine):
                                      ('tstep', 1/30),
                                      ('max_iter', 15),
                                      ('refresh_event', 0),
+                                     ('check_conn', 1),
                                      ('g_scale', 1),
                                      ('qrt', 0),
                                      ('kqrt', 1.0),
+                                     ('store_f', 0.0),
+                                     ('store_h', 0.0),
+                                     ('store_i', 0.0),
                                      )))
         self.config.add_extra("_help",
                               tol="convergence tolerance",
@@ -47,9 +52,13 @@ class TDS(BaseRoutine):
                               tstep='the initial step step size',
                               max_iter='maximum number of iterations',
                               refresh_event='refresh events at each step',
+                              check_conn='re-check connectivity after event',
                               g_scale='scale algebraic residuals with time step size',
                               qrt='quasi-real-time stepping',
                               kqrt='quasi-real-time scaling factor; kqrt > 1 means slowing down',
+                              store_f='store RHS of diff. equations',
+                              store_h='store RHS of external diff. equations',
+                              store_i='store RHS of external algeb. equations',
                               )
         self.config.add_extra("_alt",
                               tol="float",
@@ -61,10 +70,15 @@ class TDS(BaseRoutine):
                               tstep='float',
                               max_iter='>=10',
                               refresh_event=(0, 1),
-                              g_scale=(0, 1),
+                              check_conn=(0, 1),
+                              g_scale='positive',
                               qrt='bool',
-                              kqrt="positive",
+                              kqrt='positive',
+                              store_f=(0, 1),
+                              store_h=(0, 1),
+                              store_i=(0, 1),
                               )
+
         # overwrite `tf` from command line
         if system.options.get('tf') is not None:
             self.config.tf = system.options.get('tf')
@@ -97,7 +111,7 @@ class TDS(BaseRoutine):
         self._switch_idx = 0          # index into `System.switch_times`
         self._last_switch_t = -999    # the last critical time
         self.custom_event = False
-        self.mis = 1
+        self.mis = [1, 1]
         self.pbar = None
         self.callpert = None
         self.plotter = None
@@ -145,6 +159,7 @@ class TDS(BaseRoutine):
         system.dae.clear_ts()
         system.store_sparse_pattern(models=system.exist.pflow_tds)
         system.store_adder_setter(models=system.exist.pflow_tds)
+        system.store_no_check_init(models=system.exist.pflow_tds)
         system.vars_to_models()
 
         system.init(system.exist.tds, routine='tds')
@@ -167,13 +182,13 @@ class TDS(BaseRoutine):
             system.vars_to_models()
 
         # connect to data streaming server
-        if system.config.dime_enabled:
-            if system.streaming.dimec is None:
-                system.streaming.connect()
+        if system.streaming.dimec is None:
+            system.streaming.connect()
 
-        # send out system data using DiME
-        self.streaming_init()
-        self.streaming_step()
+        if system.config.dime_enabled:
+            # send out system data using DiME
+            self.streaming_init()
+            self.streaming_step()
 
         # if `dae.n == 1`, `calc_h_first` depends on new `dae.gy`
         self.calc_h()
@@ -191,7 +206,7 @@ class TDS(BaseRoutine):
             logger.error("Initialization for dynamics failed in %s.", s1)
 
         if system.dae.n == 0:
-            tqdm.write('No dynamic component loaded.')
+            tqdm.write('No differential equation detected.')
         return system.dae.xy
 
     def summary(self):
@@ -209,24 +224,23 @@ class TDS(BaseRoutine):
         if self.data_csv is not None:
             out.append(f'Loaded data from CSV file "{self.from_csv}".')
             out.append('Replaying from CSV data.')
-            out.append(f'Replay time: {self.system.dae.t}-{self.config.tf} sec.')
+            out.append(f'Replay time: {self.system.dae.t}-{self.config.tf} s.')
         else:
             out.append(f'Sparse Solver: {self.solver.sparselib.upper()}')
-            out.append(f'Simulation time: {self.system.dae.t}-{self.config.tf} sec.')
+            out.append(f'Simulation time: {self.system.dae.t}-{self.config.tf} s.')
             if self.config.fixt == 1:
-                msg = f'Fixed step size: h={1000 * self.config.tstep:.4g} msec.'
-                if self.config.shrinkt == 1:
-                    msg += ', shrink if not converged'
+                msg = f'Fixed step size: h={1000 * self.config.tstep:.4g} ms.'
+                msg += ' Shrink if not converged.' if self.config.shrinkt == 1 else ''
                 out.append(msg)
             else:
-                out.append(f'Variable step size: h0={1000 * self.config.tstep:.4g} msec.')
+                out.append(f'Variable step size: h0={1000 * self.config.tstep:.4g} ms.')
 
         out_str = '\n'.join(out)
         logger.info(out_str)
 
         if self.config.honest == 1:
-            logger.warning("The honest Newton method is used and will slow down the simulation.")
-            logger.warning("For significant speed up, set `honest=0` in TDS.config.")
+            logger.warning("The honest Newton method is being used. It will slow down the simulation.")
+            logger.warning("For speed up, set `honest=0` in TDS.config.")
 
     def run(self, no_pbar=False, no_summary=False, **kwargs):
         """
@@ -257,7 +271,7 @@ class TDS(BaseRoutine):
         if self.from_csv is not None:
             self.data_csv = self._load_csv(self.from_csv)
 
-        if no_summary is False:
+        if no_summary is False and (system.dae.t == 0):
             self.summary()
 
         # only initializing at t=0 allows to continue when `run` is called again.
@@ -265,6 +279,7 @@ class TDS(BaseRoutine):
             self.init()
         else:  # resume simulation
             resume = True
+            logger.debug("Resuming simulation from t=%.4fs.", system.dae.t)
             self._calc_h_first()
 
         self.pbar = tqdm(total=100, ncols=70, unit='%', file=sys.stdout, disable=no_pbar)
@@ -291,11 +306,18 @@ class TDS(BaseRoutine):
                 step_status = self._csv_step()
 
             if step_status:
-                # store values
-                dae.ts.store_txyz(dae.t.tolist(),
-                                  dae.xy,
-                                  self.system.get_z(models=system.exist.pflow_tds),
-                                  )
+                f_vals = dae.f if self.config.store_f else None
+                h_vals = dae.h if self.config.store_h else None
+                i_vals = dae.i if self.config.store_i else None
+
+                dae.ts.store(dae.t.tolist(),
+                             x=dae.x,
+                             y=dae.y,
+                             z=system.get_z(models=system.exist.pflow_tds),
+                             f=f_vals,
+                             h=h_vals,
+                             i=i_vals,
+                             )
 
                 self.streaming_step()
 
@@ -350,7 +372,10 @@ class TDS(BaseRoutine):
         if config.qrt:
             logger.debug('QRT headroom time: %.4g s.', self.headroom)
 
-        system.TDS.save_output()
+        # need to unpack data in case of resumed simulations.
+        system.dae.ts.unpack()
+        if not system.files.no_output:
+            self.save_output()
 
         # end data streaming
         if system.config.dime_enabled:
@@ -378,7 +403,7 @@ class TDS(BaseRoutine):
         system = self.system
         dae = self.system.dae
 
-        self.mis = 1
+        self.mis = [1, 1]
         self.niter = 0
         self.converged = False
 
@@ -415,9 +440,9 @@ class TDS(BaseRoutine):
             # is pegged by the anti-windup limiters.
 
             # solve implicit trapezoidal method (ITM) integration
-            if self.config.g_scale == 1:
-                gxs = self.h * dae.gx
-                gys = self.h * dae.gy
+            if self.config.g_scale > 0:
+                gxs = self.config.g_scale * self.h * dae.gx
+                gys = self.config.g_scale * self.h * dae.gy
             else:
                 gxs = dae.gx
                 gys = dae.gy
@@ -434,8 +459,8 @@ class TDS(BaseRoutine):
                     np.put(self.qg, key, eqval)
 
             # set or scale the algebraic residuals
-            if self.config.g_scale == 1:
-                self.qg[dae.n:] = self.h * dae.g
+            if self.config.g_scale > 0:
+                self.qg[dae.n:] = self.config.g_scale * self.h * dae.g
             else:
                 self.qg[dae.n:] = dae.g
 
@@ -466,9 +491,12 @@ class TDS(BaseRoutine):
             self.inc = inc
 
             mis = np.max(np.abs(inc))
+
             # store initial maximum mismatch
             if self.niter == 0:
-                self.mis = mis
+                self.mis[0] = mis
+            else:
+                self.mis[-1] = mis
 
             self.niter += 1
 
@@ -488,9 +516,8 @@ class TDS(BaseRoutine):
                 self._debug_ac(inc_max)
                 break
 
-            if mis > 1e6 and (mis > 1e6 * self.mis):
-                self.err_msg = 'Error increased too quickly. Convergence not likely.'
-                self.busted = True
+            if (mis > 1e6) and (mis > 1e6 * self.mis[0]):
+                self.err_msg = 'Error increased too quickly.'
                 break
 
         if not self.converged:
@@ -655,6 +682,9 @@ class TDS(BaseRoutine):
         self.fg_update(system.exist.pflow_tds)
         system.j_update(models=system.exist.pflow_tds)
 
+        # reset diff. RHS where `check_init == False`
+        system.dae.f[system.no_check_init] = 0.0
+
         # warn if variables are initialized at limits
         if system.config.warn_limits:
             for model in system.exist.pflow_tds.values():
@@ -684,35 +714,42 @@ class TDS(BaseRoutine):
         if system.options.get('verbose') == 1:
             breakpoint()
         system.exit_code += 1
+
         return False
 
     def save_output(self, npz=True):
         """
-        Save the simulation data into two files: a lst file and a npz file.
+        Save the simulation data into two files: a `.lst` file
+        and a `.npz` file.
+
+        This function saves the output regardless of the
+        `files.no_output` flag.
 
         Parameters
         ----------
         npz : bool
             True to save in npz format; False to save in npy format.
-
         Returns
         -------
         bool
             True if files are written. False otherwise.
         """
-        if self.system.files.no_output:
-            return False
 
         t0, _ = elapsed()
 
         self.system.dae.write_lst(self.system.files.lst)
+
         if npz is True:
+            np_file = self.system.files.npz
             self.system.dae.write_npz(self.system.files.npz)
         else:
+            np_file = self.system.files.npy
             self.system.dae.write_npy(self.system.files.npy)
 
         _, s1 = elapsed(t0)
-        logger.info('TDS outputs saved in %s.', s1)
+
+        logger.info('Outputs to "%s" and "%s".', self.system.files.lst, np_file)
+        logger.info('Outputs written in %s.', s1)
         return True
 
     def do_switch(self):
@@ -732,7 +769,7 @@ class TDS(BaseRoutine):
         if self._switch_idx < system.n_switches:
 
             # if the current time is close enough to the next event time
-            if np.isclose(system.dae.t, system.switch_times[self._switch_idx]):
+            if np.equal(system.dae.t, system.switch_times[self._switch_idx]):
 
                 # `_last_switch_t` is used by the Jacobian updater
                 self._last_switch_t = system.switch_times[self._switch_idx]
@@ -754,19 +791,43 @@ class TDS(BaseRoutine):
             self.custom_event = False
             ret = True
 
+        # check system connectivity after a switching
+        if ret is True and self.config.check_conn == 1:
+            system.connectivity(info=False)
+
         return ret
 
     def fg_update(self, models):
         """
-        Update `f` and `g` equations.
+        Perform one round of evaluation for one iteration step.
+        The following operations are performed in order:
+
+        - discrete flags updating through ``l_update_var``
+        - variable service updating through ``s_update_var``
+        - evaluation of the right-hand-side of ``f``
+        - equation-dependent discrete flags updating through ``l_update_eq``
+        - evaluation of the right-hand-side of ``g``
+        - collection of residuals into dae through ``fg_to_dae``.
+
         """
+
         system = self.system
         system.dae.clear_fg()
-        system.l_update_var(models=models)
+
+        system.l_update_var(models=models,
+                            niter=self.niter,
+                            err=self.mis[-1],
+                            )
+
         system.s_update_var(models=models)  # update VarService
+
+        # evalute the RHS of `f` and check the limiters (anti-windup)
+        # 12/08/2020: Moded `l_update_eq` to before `g_update`
+        #   because some algebraic variables depend on pegged states.
         system.f_update(models=models)
-        system.g_update(models=models)
         system.l_update_eq(models=models)
+
+        system.g_update(models=models)
         system.fg_to_dae()
 
     def _fg_wrapper(self, xy):
@@ -915,7 +976,7 @@ class TDS(BaseRoutine):
         self._switch_idx = 0        # index into `System.switch_times`
         self._last_switch_t = -999  # the last event time
         self.custom_event = False
-        self.mis = 1
+        self.mis = [1, 1]
         self.system.dae.t = np.array(0.0)
         self.pbar = None
         self.plotter = None
